@@ -27,3 +27,6 @@ AUTHENTICATION_BACKENDS = (
  'navigator_auth.backends.DjangoAuth',
  'navigator_auth.backends.NoAuth',
 )
+
+## AUTH_USER_MODEL: Model used for getting User Information
+AUTH_USER_MODEL = 'resources.user.User'
